package tutorial.lookandfeel;

import java.awt.Font;
import java.awt.Color;
import java.awt.Insets;
import java.awt.TextField;
import java.awt.GridBagLayout;
import java.awt.GridBagConstraints;
import javax.swing.border.Border;
import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.ButtonGroup;
import javax.swing.JPanel;
import javax.swing.JLabel;
import javax.swing.JButton;
import javax.swing.JRadioButton;
import javax.swing.JCheckBox;
import javax.swing.UIManager;
import javax.swing.SwingUtilities;

public class SwingSet extends JPanel {
    
    protected final static Color BlueBlack = new Color(0, 0, 51);
    protected final static Color PaleGray = new Color(204, 204, 204);
    
    public SwingSet() {
        GridBagLayout gridbag = new GridBagLayout();
        GridBagConstraints constraints = new GridBagConstraints();
        this.setLayout(gridbag);
        this.setForeground(BlueBlack);
        this.setBackground(PaleGray);

        constraints.insets = new Insets(9, 15, 9, 15);  // top, left, ...

        JButton submit = new JButton("Submit Registration Form");
        Border ws = BorderFactory.createEmptyBorder(1, 1, 1, 1);  // top, left, ...
        Border bevel = BorderFactory.createRaisedBevelBorder();
        submit.setBorder(BorderFactory.createCompoundBorder(bevel, ws));
        submit.setMnemonic('s');
        submit.setFont(new java.awt.Font("Dialog", Font.BOLD, 10));
        submit.setForeground(BlueBlack);
        submit.setBackground(PaleGray);

        constraints.gridx = 0;
        constraints.gridy = 0;
        gridbag.setConstraints(submit, constraints);
        this.add(submit);
        
        JCheckBox email = new JCheckBox("Notify by email", true);
        email.setFont(new java.awt.Font("Dialog", Font.PLAIN, 10));
        email.setForeground(BlueBlack);
        email.setBackground(PaleGray);

        constraints.gridx = 0;
        constraints.gridy = 1;
        gridbag.setConstraints(email, constraints);
        this.add(email);
        
        JPanel name = new JPanel();
        name.setForeground(BlueBlack);
        name.setBackground(PaleGray);
        
        JLabel fn = new JLabel("First Name:");
        fn.setFont(new java.awt.Font("Dialog", Font.PLAIN, 10));
        fn.setForeground(BlueBlack);
        fn.setBackground(PaleGray);

        TextField first = new TextField("Margaret", 25);
        first.setFont(new java.awt.Font("Dialog", Font.PLAIN, 12));
        first.setForeground(BlueBlack);
        first.setBackground(PaleGray);
        
        name.add(fn);
        name.add(first);

        constraints.gridx = 0;
        constraints.gridy = 2;
        constraints.gridwidth = 2;
        gridbag.setConstraints(name, constraints);
        this.add(name);
        
        name = new JPanel();
        name.setForeground(BlueBlack);
        name.setBackground(PaleGray);
        
        JLabel ln = new JLabel("Last Name:");
        ln.setFont(new java.awt.Font("Dialog", Font.PLAIN, 10));
        ln.setForeground(BlueBlack);
        ln.setBackground(PaleGray);

        TextField last = new TextField("Musciano", 25);
        last.setFont(new java.awt.Font("Dialog", Font.PLAIN, 12));
        last.setForeground(BlueBlack);
        last.setBackground(PaleGray);
        
        name.add(ln);
        name.add(last);

        constraints.gridx = 0;
        constraints.gridy = 3;
        constraints.gridwidth = 2;
        gridbag.setConstraints(name, constraints);
        this.add(name);
        
        JPanel options = new JPanel();       
        options.setLayout(new BoxLayout(options, BoxLayout.Y_AXIS));

        options.setForeground(BlueBlack);
        options.setBackground(PaleGray);
        
        ButtonGroup group = new ButtonGroup();

        JRadioButton always = new JRadioButton("Always", false);
        always.setFont(new java.awt.Font("Dialog", Font.BOLD, 10));
        always.setForeground(BlueBlack);
        always.setBackground(PaleGray);
        group.add(always);
        options.add(always);
        
        JRadioButton session = new JRadioButton("Once per session", true);
        session.setFont(new java.awt.Font("Dialog", Font.BOLD, 10));
        session.setForeground(BlueBlack);
        session.setBackground(PaleGray);
        group.add(session);
        options.add(session);
 
        JRadioButton never = new JRadioButton("Never", false);
        never.setFont(new java.awt.Font("Dialog", Font.BOLD, 10));
        never.setForeground(BlueBlack);
        never.setBackground(PaleGray);
        group.add(never);
        options.add(never);
        
        constraints.gridx = 2;
        constraints.gridy = 0;
        constraints.gridwidth = 1;
        constraints.gridheight = 5;
        gridbag.setConstraints(options, constraints);
        this.add(options);
    }
        
    public void setLookandFeel(String name) {
        String lnf = UIManager.getCrossPlatformLookAndFeelClassName();
        
        if(name.equals("Microsoft Windows")) {
            lnf = "com.sun.java.swing.plaf.windows.WindowsLookAndFeel";
        } else if(name.equals("CDE")) {
            lnf = "com.sun.java.swing.plaf.motif.MotifLookAndFeel";
        }
                
        try {
            UIManager.setLookAndFeel(lnf);
        } catch(Exception e) {}
        
        SwingUtilities.updateComponentTreeUI(this);
    }
}
