#!/bin/sh
#                 Sun Public License Notice
# 
# The contents of this file are subject to the Sun Public License
# Version 1.0 (the "License"). You may not use this file except in
# compliance with the License. A copy of the License is available at
# http://www.sun.com/
# 
# The Original Code is NetBeans. The Initial Developer of the Original
# Code is Sun Microsystems, Inc. Portions Copyright 1997-2000 Sun
# Microsystems, Inc. All Rights Reserved.

# loader for IDE
#
# $Id: import.sh,v 1.1.2.1 2000/12/14 16:58:07 pzajac Exp $

#
# customization
#

# the value set here can be overriden by $JAVA_PATH or the -jdkhome switch
jdkhome=""

jreflags="-Xmx96m"

#
# end of customization 
#


PRG=$0

#
# resolve symlinks
#

while [ -h "$PRG" ]; do
    ls=`ls -ld "$PRG"`
    link=`expr "$ls" : '^.*-> \(.*\)$' 2>/dev/null`
    if expr "$link" : '^/' 2> /dev/null >/dev/null; then
	PRG="$link"
    else
	PRG="`dirname $PRG`/$link"
    fi
done

progdir=`dirname $PRG`
progname=`basename $0`

idehome="$progdir/.."

# absolutize idehome

oldpwd=`pwd` ; cd ${idehome}; idehome=`pwd`; cd $oldpwd; unset oldpwd

thread_flag=""

jargs=${jreflags}
jargs="$jargs -Dnetbeans.home=$idehome"
jargs="$jargs -Djava.security.policy=$idehome/bin/ide.policy"

args=""

prefixcp=""
postfixcp=""

userdir=""

updater=org.netbeans.updater.UpdaterFrame
ide="org.netbeans.upgrade.FileCopy"

#
# defaults
#

# if JAVA_PATH is set it overrides the default in the script

if [ ! -z "$JAVA_PATH" ] ; then
    jdkhome=$JAVA_PATH
fi

#
# parse arguments
#

while [ $# -gt 0 ] ; do
    case "$1" in
        -h|-help) cat <<EOF
Usage: $0 {options} arguments

Options can be

   -h -help
        shows usage
   -jdkhome <path>
        specifies the JDK directory

   -hotspot
   -classic
   -native
   -green
        specifies the type of JVM
        
   -J<jvm_options>
        passes <jvm_option> to JVM
   -userdir <path>
        specifies userdir
   -cp:p <classpath>
        prepends <classpath> to IDE's classpath
   -cp:a <classpath>
        appends <classpath> to IDE's classpath

All other options and arguments are passed to the IDE.
See documentations for details

EOF
exit 1
;;
        -jdkhome) shift; if [ $# -gt 0 ] ; then jdkhome=$1; fi;;
        -userdir) shift; if [ $# -gt 0 ] ; then userdir=$1; fi;;
        -cp|-cp:a)
            shift;
            if [ $# -gt 0 ] ; then
                if [ ! -z "$postfixcp" ] ; then postfixcp="$postfixcp:" ; fi
                postfixcp=$postfixcp$1;
            fi
            ;;
        
        -cp:p)
            shift;
            if [ $# -gt 0 ] ; then
                if [ ! -z "$prefixcp" ] ; then prefixcp="$prefixcp:" ; fi
                prefixcp=$prefixcp$1;
            fi
            ;;
        
        -hotspot|-classic|-native|-green) thread_flag=$1;;
        -J-hotspot|-J-classic|-J-native|-J-green) thread_flag=`expr $1 : '-J\(.*\)'`;;
        -J*) jopt=`expr "$1" : '-J\(.*\)'`; jargs="$jargs \"$jopt\"";;
        *) args="$args \"$1\"" ;;
    esac
    shift
done

#
# check JDK
#

if [ -z "$jdkhome" ] ; then
    echo "Cannot find JDK. Please set the JAVA_PATH environment variable to point"
    echo "to your JDK installation directory, or use the -jdkhome switch"
    echo ""
    exit 1
fi

if [ ! -x "${jdkhome}/bin/java" ] ; then
    echo "Cannot find JDK at ${jdkhome}. Please set the JAVA_PATH"
    echo "environment variable to point to your JDK installation directory,"
    echo "or use the -jdkhome switch"
    echo ""
    exit 1
fi

#
# check userdir
#

if [ ! -z "$userdir" ] ; then
    if id | grep 'uid=0[^0-9]' >/dev/null; then
        echo "You are running IDE as root. Configurations, updated modules and"
        echo "possibly development files will be stored in the shared installation"
        printf "directory. Continue? (y/n): "
        read answer
        while [ $answer != y -a $answer != Y -a $answer != n -a $answer != N ] ; do
            printf "Please answer y or n: "
            read answer
        done
        if [ $answer != y -a $answer != Y ] ; then
            exit 1
        fi
        userdir=""
    else

        #
        # setup userdir if needed
        
        echo "Using ${userdir} as user directory...";

        if [ ! -d "${userdir}/system" ] ; then
            echo "User directory does not exist."
            echo "Setting up this user for the IDE..."

            mkdir -p "${userdir}" 2>/dev/null
            cp -r "${idehome}/Development" "${userdir}"
            
            mkdir "${userdir}/system"
            touch "${userdir}/system/project.last_hidden"
            touch "${userdir}/system/project.basic_hidden"
            mkdir "${userdir}/system/Projects" 2>/dev/null
            touch "${userdir}/system/Projects/workspace.ser_hidden"
            
            mkdir "${userdir}/modules"
            mkdir "${userdir}/lib"
            mkdir "${userdir}/lib/ext"
            mkdir "${userdir}/lib/patches"
        fi
        
        jargs="$jargs -Dnetbeans.user=$userdir"

    fi
fi

#
# increase file descriptor's limit, on Solaris it's set to 64, too small for
# fastjavac
#

ulimit -n 1024

append_jars_to_cp() {
    dir="$1"
    for ex in jar zip ; do
        if [ "`echo ${dir}/*.$ex`" != "${dir}/*.$ex" ] ; then
            for x in ${dir}/*.$ex ; do
                if [ ! -z "$cp" ] ; then cp="$cp:" ; fi
                cp="$cp$x"
            done
        fi
    done
}

build_cp() {
    base="$1"

    append_jars_to_cp "${base}/lib/patches/locale"
    append_jars_to_cp "${base}/lib/patches"
    append_jars_to_cp "${base}/lib/ext/locale"
    append_jars_to_cp "${base}/lib/ext"
    append_jars_to_cp "${base}/modules/patches"
    append_jars_to_cp "${base}/modules/ext"
    append_jars_to_cp "${base}/modules/locale"
    append_jars_to_cp "${base}/modules"
    append_jars_to_cp "${base}/lib/upgrade"

#   if [ -d "$base/lib" ] ; then
#       if [ ! -z "$cp" ] ; then cp="$cp:" ; fi
#       cp="${cp}${base}/lib"
#   fi
    
    append_jars_to_cp "${base}/lib/locale"
    append_jars_to_cp "${base}/lib"
}

#
# main loop
#


    #
    # build CLASSPATH
    #
    
    cp=""

    # userdir comes first
    
    if [ ! -z "${userdir}" ] ; then
        build_cp ${userdir}
    fi

    # idehome comes second
    
    build_cp ${idehome}
        
    # JDK tools
    
    for ex in jar zip ; do
        if [ "`echo ${jdkhome}/lib/*.$ex`" != "${jdkhome}/lib/*.$ex" ] ;then
            for x in ${jdkhome}/lib/*.$ex ; do
                if [ ! -z "$cp" ] ; then cp="$cp:" ; fi
                cp="${cp}$x"
            done
        fi
    done

    # user-specified prefix and postfix CLASSPATH
    
    if [ ! -z "${prefixcp}" ] ; then
        cp="${prefixcp}:$cp"
    fi
    
    if [ ! -z "${postfixcp}" ] ; then
        cp="$cp:${postfixcp}"
    fi

    # ${CLASSPATH}

#      if [ ! -z "${CLASSPATH}" ] ; then
#          cp="$cp:${CLASSPATH}"
#      fi
    
    #
    # let's go
    #
    
    eval $jdkhome/bin/java $thread_flag $jargs -classpath "\"$cp\"" $ide $args 






















